@@ -24,6 +24,23 @@ suite_runner = None
 old_db_config = None
 
 
+def get_runner(config):
+    runner = DjangoTestSuiteRunner(interactive=False)
+
+    if config.option.no_db:
+        runner.setup_databases = lambda: None
+        runner.teardown_databases = lambda db_config: None
+
+    return runner
+
+
+def pytest_addoption(parser):
+    group = parser.getgroup("general")
+    group._addoption('--no-db',
+                     action='store_true', dest='no_db', default=False,
+                     help='Run tests without a database')
+
+
 def _disable_south_management_command():
     management.get_commands()
     # make sure `south` migrations are disabled
@@ -35,9 +52,9 @@ def pytest_sessionstart(session):
 
     _disable_south_management_command()
 
-    suite_runner = DjangoTestSuiteRunner(interactive=False)
-
+    suite_runner = get_runner(session.config)
     suite_runner.setup_test_environment()
+
     old_db_config = suite_runner.setup_databases()
 
     settings.DEBUG_PROPAGATE_EXCEPTIONS = True
@@ -68,7 +85,7 @@ def pytest_runtest_setup(item):
         clear_url_caches()
 
     # Invoke Django code to prepare the environment for the test run
-    if not is_django_unittest(item):
+    if not item.config.option.no_db and not is_django_unittest(item):
         django_setup_item(item)
 
 
@@ -76,7 +93,7 @@ def pytest_runtest_teardown(item):
     global _old_urlconf
 
     # Call Django code to tear down
-    if not is_django_unittest(item):
+    if not item.config.option.no_db and not is_django_unittest(item):
         django_teardown_item(item)
 
     if hasattr(item, 'urls') and _old_urlconf is not None:
